<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author damiano <damiano@spagnuolo.eu>
 * @author Torpedo <dgtorpedo@gmail.com>
 * @author Giorgio Vecchiocattivi <giorgio@vecchio.it>
 * @author Roberto Bolli [http://www.rbnet.it/]
 * @author Silvia Sargentoni <polinnia@tin.it>
 * @author Diego Pierotto <ita.translations@tiscali.it>
 * @author Lorenzo Breda <lbreda@gmail.com>
 * @author robocap <robocap1@gmail.com>
 * @author Matteo Carnevali <rekstorm@gmail.com>
 * @author Osman Tekin <osman.tekin93@hotmail.it>
 * @author Jacopo Corbetta <jacopo.corbetta@gmail.com>
 * @author Matteo Pasotti <matteo@xquiet.eu>
 * @author Edmondo Di Tucci <snarchio@gmail.com>
 * @author Claudio Lanconelli <lancos@libero.it>
 * @author Mirko <malisan.mirko@gmail.com>
 * @author Francesco <francesco.cavalli@hotmail.com>
 * @author Fabio <fabioslurp@yahoo.it>
 * @author Maurizio <mcannavo@katamail.com>
 * @author Riccardo <riccardofila@gmail.com>
 * @author Paolo <paolopoz12@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Modifica questa pagina';
$lang['btn_source']            = 'Mostra sorgente';
$lang['btn_show']              = 'Mostra pagina';
$lang['btn_create']            = 'Crea questa pagina';
$lang['btn_search']            = 'Cerca';
$lang['btn_save']              = 'Salva';
$lang['btn_preview']           = 'Anteprima';
$lang['btn_top']               = 'Torna su';
$lang['btn_newer']             = '<< più recenti';
$lang['btn_older']             = 'meno recenti >>';
$lang['btn_revs']              = 'Revisioni precedenti';
$lang['btn_recent']            = 'Ultime modifiche';
$lang['btn_upload']            = 'Invia file';
$lang['btn_cancel']            = 'Annulla';
$lang['btn_index']             = 'Indice';
$lang['btn_secedit']           = 'Modifica';
$lang['btn_login']             = 'Entra';
$lang['btn_logout']            = 'Esci';
$lang['btn_admin']             = 'Amministrazione';
$lang['btn_update']            = 'Aggiorna';
$lang['btn_delete']            = 'Elimina';
$lang['btn_back']              = 'Indietro';
$lang['btn_backlink']          = 'Puntano qui';
$lang['btn_subscribe']         = 'Sottoscrivi modifiche';
$lang['btn_profile']           = 'Aggiorna profilo';
$lang['btn_reset']             = 'Annulla';
$lang['btn_resendpwd']         = 'Imposta nuova password';
$lang['btn_draft']             = 'Modifica bozza';
$lang['btn_recover']           = 'Ripristina bozza';
$lang['btn_draftdel']          = 'Elimina bozza';
$lang['btn_revert']            = 'Ripristina';
$lang['btn_register']          = 'Registrazione';
$lang['btn_apply']             = 'Applica';
$lang['btn_media']             = 'Gestore Media';
$lang['btn_deleteuser']        = 'Rimuovi il mio account';
$lang['btn_img_backto']        = 'Torna a %s';
$lang['btn_mediaManager']      = 'Guarda nel gestore media';
$lang['loggedinas']            = 'Collegato come:';
$lang['user']                  = 'Nome utente';
$lang['pass']                  = 'Password';
$lang['newpass']               = 'Nuova password';
$lang['oldpass']               = 'Conferma password attuale';
$lang['passchk']               = 'Ripeti password';
$lang['remember']              = 'Memorizza nome utente e password';
$lang['fullname']              = 'Nome completo';
$lang['email']                 = 'Email';
$lang['profile']               = 'Profilo utente';
$lang['badlogin']              = 'Il nome utente o la password non sono validi.';
$lang['badpassconfirm']        = 'La password è errata';
$lang['minoredit']             = 'Modifiche minori';
$lang['draftdate']             = 'Bozza salvata in automatico il';
$lang['nosecedit']             = 'La pagina è stata modificata nel frattempo; è impossibile modificare solo la sezione scelta, quindi è stata caricata la pagina intera.';
$lang['searchcreatepage']      = 'Se non hai trovato ciò che stavi cercando, puoi creare o modificare la pagina %s, nominata dopo la tua query.';
$lang['search_fullresults']    = 'Risultati del testo integrale';
$lang['js']['search_toggle_tools'] = 'Attiva o disattiva gli strumenti di ricerca';
$lang['js']['willexpire']      = 'Il tuo blocco su questa pagina scadrà tra circa un minuto.\nPer evitare incongruenze usa il pulsante di anteprima per prolungare il periodo di blocco.';
$lang['js']['notsavedyet']     = 'Le modifiche non salvate andranno perse.';
$lang['js']['searchmedia']     = 'Cerca file';
$lang['js']['keepopen']        = 'Tieni la finestra aperta durante la selezione';
$lang['js']['hidedetails']     = 'Nascondi Dettagli';
$lang['js']['mediatitle']      = 'Impostazioni link';
$lang['js']['mediadisplay']    = 'Tipo link';
$lang['js']['mediaalign']      = 'Allineamento';
$lang['js']['mediasize']       = 'Dimensioni immagine';
$lang['js']['mediatarget']     = 'Target del link';
$lang['js']['mediaclose']      = 'Chiudi';
$lang['js']['mediainsert']     = 'Inserisci';
$lang['js']['mediadisplayimg'] = 'Mostra l\'immagine.';
$lang['js']['mediadisplaylnk'] = 'Mostra solo il link.';
$lang['js']['mediasmall']      = 'Versione piccola';
$lang['js']['mediamedium']     = 'Versione media';
$lang['js']['medialarge']      = 'Versione grande';
$lang['js']['mediaoriginal']   = 'Versione originale';
$lang['js']['medialnk']        = 'Link alla pagina dei dettagli';
$lang['js']['mediadirect']     = 'Link all\'originale';
$lang['js']['medianolnk']      = 'No link';
$lang['js']['medianolink']     = 'Non linkare l\'immagine.';
$lang['js']['medialeft']       = 'Allinea l\'immagine a sinistra.';
$lang['js']['mediaright']      = 'Allinea l\'immagine a destra.';
$lang['js']['mediacenter']     = 'Allinea l\'immagine al centro.';
$lang['js']['medianoalign']    = 'Non allineare.';
$lang['js']['nosmblinks']      = 'I collegamenti con le risorse condivise di Windows funzionano solo con Microsoft Internet Explorer.
È comunque possibile copiare e incollare il collegamento.';
$lang['js']['linkwiz']         = 'Collegamento guidato';
$lang['js']['linkto']          = 'Collega a:';
$lang['js']['del_confirm']     = 'Eliminare veramente questa voce?';
$lang['js']['restore_confirm'] = 'Vuoi davvero ripristinare questa versione?';
$lang['js']['media_diff']      = 'Guarda le differenze:';
$lang['js']['media_diff_both'] = 'Fianco a Fianco';
$lang['js']['media_diff_opacity'] = 'Trasparire';
$lang['js']['media_diff_portions'] = 'rubare';
$lang['js']['media_select']    = 'Seleziona files..';
$lang['js']['media_upload_btn'] = 'Upload';
$lang['js']['media_done_btn']  = 'Fatto';
$lang['js']['media_drop']      = 'Sgancia i files qui per caricarli';
$lang['js']['media_cancel']    = 'rimuovi';
$lang['js']['media_overwrt']   = 'Sovrascrivi i file esistenti';
$lang['search_exact_match']    = 'Corrispondenza esatta';
$lang['search_starts_with']    = 'Comincia con';
$lang['search_ends_with']      = 'Finisce con';
$lang['search_contains']       = 'Contiene';
$lang['search_custom_match']   = 'Personalizza';
$lang['search_any_ns']         = 'Qualsiasi spazio dei nomi';
$lang['search_any_time']       = 'Ogni volta';
$lang['regmissing']            = 'Devi riempire tutti i campi.';
$lang['reguexists']            = 'Il nome utente inserito esiste già.';
$lang['regsuccess']            = 'L\'utente è stato creato. La password è stata spedita via email.';
$lang['regsuccess2']           = 'L\'utente è stato creato.';
$lang['regfail']               = 'L\'utente non può essere creato.';
$lang['regmailfail']           = 'Sembra che ci sia stato un errore nell\'invio della email. Contatta l\'amministratore!';
$lang['regbadmail']            = 'L\'indirizzo email fornito sembra essere non valido - se pensi che ci sia un errore contatta l\'amministratore';
$lang['regbadpass']            = 'Le due password inserite non coincidono, prova di nuovo.';
$lang['regpwmail']             = 'La tua password per DokuWiki';
$lang['reghere']               = 'Non sei ancora registrato? Registrati qui.';
$lang['profna']                = 'Questo wiki non supporta modifiche al profilo';
$lang['profnochange']          = 'Nessuna modifica, niente da aggiornare.';
$lang['profnoempty']           = 'Nome o indirizzo email vuoti non sono consentiti.';
$lang['profchanged']           = 'Aggiornamento del profilo utente riuscito.';
$lang['profnodelete']          = 'Questa wiki non supporta la cancellazione degli utenti';
$lang['profdeleteuser']        = 'Elimina account';
$lang['profdeleted']           = 'Il tuo account utente è stato rimosso da questa wiki';
$lang['profconfdelete']        = 'Voglio rimuovere il mio account da questa wiki. <br/> Questa operazione non può essere annullata.';
$lang['profconfdeletemissing'] = 'La check box di conferma non è selezionata';
$lang['proffail']              = 'Il profilo utente non è stato aggiornato.';
$lang['pwdforget']             = 'Hai dimenticato la password? Richiedine una nuova';
$lang['resendna']              = 'Questo wiki non supporta l\'invio di nuove password.';
$lang['resendpwd']             = 'Imposta nuova password per';
$lang['resendpwdmissing']      = 'Devi riempire tutti i campi.';
$lang['resendpwdnouser']       = 'Impossibile trovare questo utente nel database.';
$lang['resendpwdbadauth']      = 'Spiacenti, questo codice di autorizzazione non è valido. Assicurati di aver usato il link completo di conferma.';
$lang['resendpwdconfirm']      = 'Un link di conferma è stato spedito via email.';
$lang['resendpwdsuccess']      = 'La nuova password è stata spedita via email.';
$lang['license']               = 'Ad eccezione da dove è diversamente indicato, il contenuto di questo wiki è soggetto alla seguente licenza:';
$lang['licenseok']             = 'Nota: modificando questa pagina accetti di rilasciare il contenuto sotto la seguente licenza:';
$lang['searchmedia']           = 'Cerca file di nome:';
$lang['searchmedia_in']        = 'Cerca in %s';
$lang['txt_upload']            = 'Seleziona un file da caricare:';
$lang['txt_filename']          = 'Carica come (opzionale):';
$lang['txt_overwrt']           = 'Sovrascrivi file esistente';
$lang['maxuploadsize']         = 'Upload max. %s per ogni file.';
$lang['lockedby']              = 'Attualmente bloccato da:';
$lang['lockexpire']            = 'Il blocco scade alle:';
$lang['rssfailed']             = 'Si è verificato un errore cercando questo feed: ';
$lang['nothingfound']          = 'Nessun risultato trovato.';
$lang['mediaselect']           = 'Selezione dei file';
$lang['uploadsucc']            = 'Invio riuscito';
$lang['uploadfail']            = 'Invio fallito. È possibile che si tratti di un problema di permessi.';
$lang['uploadwrong']           = 'Invio rifiutato. Questa estensione di file non è ammessa';
$lang['uploadexist']           = 'Il file esiste già. Invio annullato.';
$lang['uploadbadcontent']      = 'Il tipo di contenuto caricato non corrisponde all\'estensione del file %s.';
$lang['uploadspam']            = 'Il caricamento è stato bloccato come spam perché presente nella lista nera.';
$lang['uploadxss']             = 'Il caricamento è stato bloccato perchè il contenuto potrebbe essere un virus o presentare problemi di sicurezza.';
$lang['uploadsize']            = 'Il file caricato è troppo grande. (massimo %s)';
$lang['deletesucc']            = 'Il file "%s" è stato eliminato.';
$lang['deletefail']            = '"%s" non può essere eliminato - verifica i permessi.';
$lang['mediainuse']            = 'Il file "%s" non è stato eliminato - è ancora in uso.';
$lang['namespaces']            = 'Categorie';
$lang['mediafiles']            = 'File disponibili in';
$lang['accessdenied']          = 'Non sei autorizzato a vedere questa pagina.';
$lang['mediausage']            = 'Usa la seguente sintassi per riferirti a questo file:';
$lang['mediaview']             = 'Mostra file originale';
$lang['mediaroot']             = 'directory principale';
$lang['mediaupload']           = 'Carica un file nella categoria attuale. Per creare sottocategorie, falle precedere dal nome del file nella casella "Carica come", separandole da due punti (:).';
$lang['mediaextchange']        = 'Estensione del file modificata da .%s a .%s!';
$lang['reference']             = 'Riferimenti a';
$lang['ref_inuse']             = 'Il file non può essere eliminato in quanto è ancora utilizzato dalle seguenti pagine:';
$lang['ref_hidden']            = 'Sono presenti alcuni riferimenti a pagine per le quali non hai i permessi di lettura';
$lang['hits']                  = 'Occorrenze trovate';
$lang['quickhits']             = 'Pagine trovate';
$lang['toc']                   = 'Indice';
$lang['current']               = 'versione attuale';
$lang['yours']                 = 'la tua versione';
$lang['diff']                  = 'differenze con la versione attuale';
$lang['diff2']                 = 'differenze tra le versioni selezionate';
$lang['difflink']              = 'Link a questa pagina di confronto';
$lang['diff_type']             = 'Guarda le differenze:';
$lang['diff_inline']           = 'In linea';
$lang['diff_side']             = 'Fianco a Fianco';
$lang['diffprevrev']           = 'Revisione precedente';
$lang['diffnextrev']           = 'Prossima revisione';
$lang['difflastrev']           = 'Ultima revisione';
$lang['diffbothprevrev']       = 'Entrambe le parti precedenti la revisione';
$lang['diffbothnextrev']       = 'Entrambe le parti successive la revisione';
$lang['line']                  = 'Linea';
$lang['breadcrumb']            = 'Traccia:';
$lang['youarehere']            = 'Ti trovi qui:';
$lang['lastmod']               = 'Ultima modifica:';
$lang['by']                    = 'da';
$lang['deleted']               = 'eliminata';
$lang['created']               = 'creata';
$lang['restored']              = 'versione precedente ripristinata (%s)';
$lang['external_edit']         = 'modifica esterna';
$lang['summary']               = 'Oggetto della modifica';
$lang['noflash']               = 'E\' necessario <a href="http://www.adobe.com/products/flashplayer/">il plugin Adobe Flash</a> per visualizzare questo contenuto.';
$lang['download']              = 'Scarica lo "snippet"';
$lang['tools']                 = 'Strumenti';
$lang['user_tools']            = 'Strumenti Utente';
$lang['site_tools']            = 'Strumenti Sito';
$lang['page_tools']            = 'Strumenti Pagina';
$lang['skip_to_content']       = 'salta al contenuto';
$lang['sidebar']               = 'Barra laterale';
$lang['mail_newpage']          = 'pagina aggiunta:';
$lang['mail_changed']          = 'pagina modificata:';
$lang['mail_subscribe_list']   = 'pagine modificate nella categoria:';
$lang['mail_new_user']         = 'nuovo utente:';
$lang['mail_upload']           = 'file caricato:';
$lang['changes_type']          = 'Guarda cambiamenti di';
$lang['pages_changes']         = 'Pagine';
$lang['media_changes']         = 'File multimediali';
$lang['both_changes']          = 'Sia pagine che media files';
$lang['qb_bold']               = 'Grassetto';
$lang['qb_italic']             = 'Corsivo';
$lang['qb_underl']             = 'Sottolineato';
$lang['qb_code']               = 'Codice';
$lang['qb_strike']             = 'Barrato';
$lang['qb_h1']                 = 'Intestazione di livello 1';
$lang['qb_h2']                 = 'Intestazione di livello 2';
$lang['qb_h3']                 = 'Intestazione di livello 3';
$lang['qb_h4']                 = 'Intestazione di livello 4';
$lang['qb_h5']                 = 'Intestazione di livello 5';
$lang['qb_h']                  = 'Titolo';
$lang['qb_hs']                 = 'Seleziona il titolo';
$lang['qb_hplus']              = 'Titolo superiore';
$lang['qb_hminus']             = 'Titolo inferiore';
$lang['qb_hequal']             = 'Titolo dello stesso livello';
$lang['qb_link']               = 'Collegamento interno';
$lang['qb_extlink']            = 'Collegamento esterno';
$lang['qb_hr']                 = 'Riga orizzontale';
$lang['qb_ol']                 = 'Elenco numerato';
$lang['qb_ul']                 = 'Elenco puntato';
$lang['qb_media']              = 'Inserisci immagini o altri file';
$lang['qb_sig']                = 'Inserisci la firma';
$lang['qb_smileys']            = 'Smiley';
$lang['qb_chars']              = 'Caratteri speciali';
$lang['upperns']               = 'vai alla categoria principale';
$lang['metaedit']              = 'Modifica metadati';
$lang['metasaveerr']           = 'Scrittura metadati fallita';
$lang['metasaveok']            = 'Metadati salvati';
$lang['img_title']             = 'Titolo:';
$lang['img_caption']           = 'Descrizione:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Nome File:';
$lang['img_fsize']             = 'Dimensione:';
$lang['img_artist']            = 'Autore:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Formato:';
$lang['img_camera']            = 'Camera:';
$lang['img_keywords']          = 'Parole chiave:';
$lang['img_width']             = 'Larghezza:';
$lang['img_height']            = 'Altezza:';
$lang['subscr_subscribe_success'] = 'Aggiunto %s alla lista di sottoscrizioni %s';
$lang['subscr_subscribe_error'] = 'Impossibile aggiungere %s alla lista di sottoscrizioni %s';
$lang['subscr_subscribe_noaddress'] = 'Non esiste alcun indirizzo associato al tuo account, non puoi essere aggiunto alla lista di sottoscrizioni';
$lang['subscr_unsubscribe_success'] = 'Rimosso %s dalla lista di sottoscrizioni %s';
$lang['subscr_unsubscribe_error'] = 'Impossibile rimuovere %s dalla lista di sottoscrizioni %s';
$lang['subscr_already_subscribed'] = '%s è già iscritto a %s';
$lang['subscr_not_subscribed'] = '%s non è iscritto a %s';
$lang['subscr_m_not_subscribed'] = 'Attualmente non sei iscritto alla pagina o categoria corrente';
$lang['subscr_m_new_header']   = 'Aggiungi sottoscrizione';
$lang['subscr_m_current_header'] = 'Sottoscrizioni attuali';
$lang['subscr_m_unsubscribe']  = 'Rimuovi sottoscrizione';
$lang['subscr_m_subscribe']    = 'Sottoscrivi';
$lang['subscr_m_receive']      = 'Ricevi';
$lang['subscr_style_every']    = 'email per ogni modifica';
$lang['subscr_style_digest']   = 'email di riassunto dei cambiamenti per ogni pagina (ogni %.2f giorni)';
$lang['subscr_style_list']     = 'lista delle pagine cambiate dall\'ultima email (ogni %.2f giorni)';
$lang['authtempfail']          = 'L\'autenticazione è temporaneamente non disponibile. Se questa situazione persiste, informa l\'amministratore di questo wiki.';
$lang['i_chooselang']          = 'Scegli la lingua';
$lang['i_installer']           = 'Installazione di DokuWiki';
$lang['i_wikiname']            = 'Nome Wiki';
$lang['i_enableacl']           = 'Abilita ACL (consigliato)';
$lang['i_superuser']           = 'Amministratore';
$lang['i_problems']            = 'Si sono verificati problemi durante l\'installazione, indicati di seguito. Non è possibile continuare finché non saranno risolti.';
$lang['i_modified']            = 'Per motivi di sicurezza questa procedura funziona solamente con un\'installazione Dokuwiki nuova e non modificata.
Prova a estrarre di nuovo i file dal pacchetto scaricato oppure consulta le
<a href="http://dokuwiki.org/install">istruzioni per l\'installazione di Dokuwiki</a>';
$lang['i_funcna']              = 'La funzione PHP <code>%s</code> non è disponibile. Forse è stata disabilitata dal tuo provider per qualche motivo?';
$lang['i_phpver']              = 'La versione di PHP <code>%s</code> è inferiore a quella richiesta <code>%s</code>. Devi aggiornare l\'installazione di PHP.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload deve essere disabilitato in php.ini per eseguire DokuWiki.';
$lang['i_permfail']            = 'DokuWiki non può scrivere <code>%s</code>. E\' necessario correggere i permessi per questa directory!';
$lang['i_confexists']          = '<code>%s</code> esiste già';
$lang['i_writeerr']            = 'Impossibile creare <code>%s</code>. E\' necessario verificare i permessi della directory o del file oppure creare il file manualmente.';
$lang['i_badhash']             = 'dokuwiki.php (hash=<code>%s</code>) non riconosciuto o modificato';
$lang['i_badval']              = '<code>%s</code> - valore vuoto o non valido';
$lang['i_success']             = 'La configurazione è stata completata correttamente. Ora è possibile eliminare il file install.php. Poi, visita <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
$lang['i_failure']             = 'Si sono verificati errori durante la scrittura dei file di configurazione. Potrebbe essere necessario correggerli manualmente prima di poter utilizzare <a href="doku.php?id=wiki:welcome">il tuo nuovo DokuWiki</a>.';
$lang['i_policy']              = 'Regole di accesso iniziali';
$lang['i_pol0']                = 'Wiki Aperto (lettura, scrittura, caricamento file per tutti)';
$lang['i_pol1']                = 'Wiki Pubblico (lettura per tutti, scrittura e caricamento file per gli utenti registrati)';
$lang['i_pol2']                = 'Wiki Chiuso (lettura, scrittura, caricamento file solamente per gli utenti registrati)';
$lang['i_allowreg']            = 'Permetti agli utenti di registrarsi';
$lang['i_retry']               = 'Riprova';
$lang['i_license']             = 'Per favore scegli la licenza sotto cui vuoi rilasciare il contenuto:';
$lang['i_license_none']        = 'Non mostrare informazioni sulla licenza';
$lang['i_pop_field']           = 'Per favore, aiutaci ad incrementare la conoscenza di DokuWiki:';
$lang['i_pop_label']           = 'Mensilmente invia una statistica d\'uso anonima di DokuWiki agli sviluppatori';
$lang['recent_global']         = 'Stai attualmente vedendo le modifiche effettuate nell\'area <b>%s</b>. Puoi anche <a href="%s">vedere le modifiche recenti dell\'intero wiki</a>.';
$lang['years']                 = '%d anni fa';
$lang['months']                = '%d mesi fa';
$lang['weeks']                 = '%d settimane fa';
$lang['days']                  = '%d giorni fa';
$lang['hours']                 = '%d ore fa';
$lang['minutes']               = '%d minuti fa';
$lang['seconds']               = '%d secondi fa';
$lang['wordblock']             = 'La modifica non è stata salvata perché contiene testo bloccato (spam).';
$lang['media_uploadtab']       = 'Upload';
$lang['media_searchtab']       = 'Cerca';
$lang['media_file']            = 'File';
$lang['media_viewtab']         = 'Guarda';
$lang['media_edittab']         = 'Modifica';
$lang['media_historytab']      = 'Storia';
$lang['media_list_thumbs']     = 'Miniatura';
$lang['media_list_rows']       = 'Righe';
$lang['media_sort_name']       = 'Nome';
$lang['media_sort_date']       = 'Data';
$lang['media_namespaces']      = 'Scegli il namespace';
$lang['media_files']           = 'File in %s';
$lang['media_upload']          = 'Upload al %s';
$lang['media_search']          = 'Cerca in %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s a %s';
$lang['media_edit']            = 'Modifica %s';
$lang['media_history']         = 'Storia di %s';
$lang['media_meta_edited']     = 'metadata modificati';
$lang['media_perm_read']       = 'Spiacente, non hai abbastanza privilegi per leggere i files.';
$lang['media_perm_upload']     = 'Spiacente, non hai abbastanza privilegi per caricare files.';
$lang['media_update']          = 'Carica nuova versione';
$lang['media_restore']         = 'Ripristina questa versione';
$lang['media_acl_warning']     = 'Questa lista potrebbe non essere completa a causa di restrizioni ACL e pagine nascoste.';
$lang['currentns']             = 'Namespace corrente';
$lang['searchresult']          = 'Risultati della ricerca';
$lang['plainhtml']             = 'HTML';
$lang['wikimarkup']            = 'Marcatura wiki';
$lang['page_nonexist_rev']     = 'Pagina non esistente a %s. E\' stata creata successivamente a <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Impossibile eseguire l\'analisi al parametro "%s".';
$lang['email_signature_text']  = 'Questa email è stata generata dal DokuWiki all\'indirizzo
@DOKUWIKIURL@';
